import pyfoci
import matplotlib.pyplot as plt
import numpy as np
import multiprocessing as mp

# Update these:
microscope_setting = 'pyfoci/microscopes/Microscopes.json' # point to pyfoci source code directory
damage = 'PATH/TO/MICROSCOPEFILE'
time_array = [1800, 7200, 21600, 86400]
microscopes = [('airyscan', '10x'), ('airyscan', '20x'), ('airyscan', '40x'), ('airyscan', '63x'), ('airyscan', '100x'),('gSTED', '63x'),('MultiPhoton', '63x'),('Phenix', '63x'),('STED', '63x'), ('STED', '20x'), ('STED', '25x'), ('STED', '40x'), ('STED', '100x'), ('Lowlight', '20x'), ('Lowlight', '40x'), ('Lowlight', '100x'), ('gSTED', '23x'), ('gSTED', '40x'), ('gSTED', '100x'), ('MultiPhoton', '10x'), ('MultiPhoton', '25x'), ('MultiPhoton', '40x'), ('Phenix', '20x'), ('Phenix', '40x')]

# Example function for making these figures
def make_figs(microscope):
    for time in time_array:
        microscope_object = pyfoci.microscope.Microscope(damage, microscope_setting, cell_radius=14)
        microscope_object.define_microscope_list(microscope[0], microscope[1])
        microscope_object.mapping_breaks()
        world = microscope_object.create_world()
        broken_world = microscope_object.place_breaks(world, time)
        microscope_object.max_value_world()
        view_object = pyfoci.view.View(microscope_object, broken_world)
        if time == 1800: # This stops self normalisation for every time point
            max_val = np.max(broken_world)
        save_name=f'{microscope[0]}_{microscope[1]}_{time}s.png'
        view_object.viewer()
        view_object.save_microscope_image(save_name, save_path='ExampleH2AXMarkerImages')
        counter = pyfoci.fociCounter.FociCounter()
        counter.parse_input(view_object.view_adjusted_image)
        # Update these parameters depending on H2AX or DSB Marker types
        counter.detect_foci(min_sigma=2, max_sigma=20, num_sigma=3, threshold=max_val*0.04)
        counter.save_detected_array(f'ExampleH2AXMarkerImagesDetected/{save_name}', max_val)
        plt.clf()

# Some simple multi-threading as H2AX images can be slow to process       
pool = mp.Pool()
pool.map(make_figs,microscopes)
